@@ -1,6 +1,8 @@
 package App::GitGot;
-$App::GitGot::VERSION = '1.20';
+$App::GitGot::VERSION = '1.21';
 use Mouse;
+use strict;
+use warnings;
 extends 'MouseX::App::Cmd';
 # ABSTRACT: A tool to make it easier to manage multiple git repositories.
 
@@ -20,7 +22,7 @@ App::GitGot - A tool to make it easier to manage multiple git repositories.
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 SYNOPSIS
 
