@@ -1,8 +1,10 @@
 package App::GitGot::Command;
-$App::GitGot::Command::VERSION = '1.20';
+$App::GitGot::Command::VERSION = '1.21';
 # ABSTRACT: Base class for App::GitGot commands
 use Mouse;
 extends 'MouseX::App::Cmd::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -618,7 +620,7 @@ App::GitGot::Command - Base class for App::GitGot commands
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 METHODS
 
