@@ -1,8 +1,10 @@
 package App::GitGot::Command::add;
-$App::GitGot::Command::add::VERSION = '1.20';
+$App::GitGot::Command::add::VERSION = '1.21';
 # ABSTRACT: add a new repo to your config
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -144,7 +146,7 @@ App::GitGot::Command::add - add a new repo to your config
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 SYNOPSIS
 
