@@ -1,8 +1,10 @@
 package App::GitGot::Command::chdir;
-$App::GitGot::Command::chdir::VERSION = '1.20';
+$App::GitGot::Command::chdir::VERSION = '1.21';
 # ABSTRACT: open a subshell in a selected project
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -39,7 +41,7 @@ App::GitGot::Command::chdir - open a subshell in a selected project
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
