@@ -1,8 +1,10 @@
 package App::GitGot::Command::clone;
-$App::GitGot::Command::clone::VERSION = '1.20';
+$App::GitGot::Command::clone::VERSION = '1.21';
 # ABSTRACT: clone a remote repo and add it to your config
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -73,7 +75,7 @@ App::GitGot::Command::clone - clone a remote repo and add it to your config
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
