@@ -1,9 +1,11 @@
 package App::GitGot::Command::do;
-$App::GitGot::Command::do::VERSION = '1.20';
+$App::GitGot::Command::do::VERSION = '1.21';
 # ABSTRACT: run command in many repositories
-use 5.010;
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
+use 5.010;
 use namespace::autoclean;
 
 use Capture::Tiny qw/ capture_stdout /;
@@ -70,7 +72,7 @@ App::GitGot::Command::do - run command in many repositories
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
