@@ -1,8 +1,10 @@
 package App::GitGot::Command::fetch;
-$App::GitGot::Command::fetch::VERSION = '1.20';
+$App::GitGot::Command::fetch::VERSION = '1.21';
 # ABSTRACT: fetch remotes for managed repositories
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -29,7 +31,7 @@ App::GitGot::Command::fetch - fetch remotes for managed repositories
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
