@@ -1,8 +1,10 @@
 package App::GitGot::Command::fork;
-$App::GitGot::Command::fork::VERSION = '1.20';
+$App::GitGot::Command::fork::VERSION = '1.21';
 # ABSTRACT: fork a github repo
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -101,7 +103,7 @@ App::GitGot::Command::fork - fork a github repo
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
