@@ -1,8 +1,10 @@
 package App::GitGot::Command::gc;
-$App::GitGot::Command::gc::VERSION = '1.20';
+$App::GitGot::Command::gc::VERSION = '1.21';
 # ABSTRACT: Run the 'gc' command to garbage collect in git repos
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -48,7 +50,7 @@ App::GitGot::Command::gc - Run the 'gc' command to garbage collect in git repos
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
