@@ -1,8 +1,10 @@
 package App::GitGot::Command::lib;
-$App::GitGot::Command::lib::VERSION = '1.20';
+$App::GitGot::Command::lib::VERSION = '1.21';
 # ABSTRACT: Generate a lib listing off a .gotlib file
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -87,7 +89,7 @@ App::GitGot::Command::lib - Generate a lib listing off a .gotlib file
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 SYNOPSIS
 
