@@ -1,8 +1,10 @@
 package App::GitGot::Command::list;
-$App::GitGot::Command::list::VERSION = '1.20';
+$App::GitGot::Command::list::VERSION = '1.21';
 # ABSTRACT: list managed repositories
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -67,7 +69,7 @@ App::GitGot::Command::list - list managed repositories
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
