@@ -1,8 +1,10 @@
 package App::GitGot::Command::move;
-$App::GitGot::Command::move::VERSION = '1.20';
+$App::GitGot::Command::move::VERSION = '1.21';
 # ABSTRACT: move a repo in a new directory
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -27,7 +29,7 @@ sub _execute {
   dir($self->destination)->mkpath if @repos > 1;
 
   for my $repo ( @repos ) {
-    $target_dir = -d $self->destination
+    my $target_dir = -d $self->destination
       ? dir($self->destination)->subdir( dir($repo->path)->basename )
       : $self->destination;
 
@@ -57,7 +59,7 @@ App::GitGot::Command::move - move a repo in a new directory
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
