@@ -1,8 +1,10 @@
 package App::GitGot::Command::mux;
-$App::GitGot::Command::mux::VERSION = '1.20';
+$App::GitGot::Command::mux::VERSION = '1.21';
 # ABSTRACT: open a tmux window for a selected project
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -91,7 +93,7 @@ App::GitGot::Command::mux - open a tmux window for a selected project
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
