@@ -1,8 +1,10 @@
 package App::GitGot::Command::push;
-$App::GitGot::Command::push::VERSION = '1.20';
+$App::GitGot::Command::push::VERSION = '1.21';
 # ABSTRACT: Push local changes to the default remote in git repos
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -55,7 +57,7 @@ App::GitGot::Command::push - Push local changes to the default remote in git rep
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
