@@ -1,8 +1,10 @@
 package App::GitGot::Command::remove;
-$App::GitGot::Command::remove::VERSION = '1.20';
+$App::GitGot::Command::remove::VERSION = '1.21';
 # ABSTRACT: remove a managed repository from your config
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -59,7 +61,7 @@ App::GitGot::Command::remove - remove a managed repository from your config
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
