@@ -1,8 +1,10 @@
 package App::GitGot::Command::tag;
-$App::GitGot::Command::tag::VERSION = '1.20';
+$App::GitGot::Command::tag::VERSION = '1.21';
 # ABSTRACT: list/add/remove tags for the current repository
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -104,7 +106,7 @@ App::GitGot::Command::tag - list/add/remove tags for the current repository
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 SYNOPSIS
 
