@@ -1,8 +1,10 @@
 package App::GitGot::Command::that;
-$App::GitGot::Command::that::VERSION = '1.20';
+$App::GitGot::Command::that::VERSION = '1.21';
 # ABSTRACT: check if a given repository is managed
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -33,7 +35,7 @@ App::GitGot::Command::that - check if a given repository is managed
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
