@@ -1,8 +1,10 @@
 package App::GitGot::Command::this;
-$App::GitGot::Command::this::VERSION = '1.20';
+$App::GitGot::Command::this::VERSION = '1.21';
 # ABSTRACT: check if the current repository is managed
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -31,7 +33,7 @@ App::GitGot::Command::this - check if the current repository is managed
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
