@@ -1,8 +1,10 @@
 package App::GitGot::Command::update_status;
-$App::GitGot::Command::update_status::VERSION = '1.20';
+$App::GitGot::Command::update_status::VERSION = '1.21';
 # ABSTRACT: update managed repositories then display their status
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -33,7 +35,7 @@ App::GitGot::Command::update_status - update managed repositories then display t
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
