@@ -1,8 +1,10 @@
 package App::GitGot::Command::version;
-$App::GitGot::Command::version::VERSION = '1.20';
+$App::GitGot::Command::version::VERSION = '1.21';
 # ABSTRACT: display application version
 use Mouse;
 extends 'App::GitGot::Command';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -23,7 +25,7 @@ App::GitGot::Command::version - display application version
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
