@@ -1,7 +1,9 @@
 package App::GitGot::Outputter;
-$App::GitGot::Outputter::VERSION = '1.20';
+$App::GitGot::Outputter::VERSION = '1.21';
 # ABSTRACT: Generic base class for outputting formatted messages.
 use Mouse;
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -60,7 +62,7 @@ App::GitGot::Outputter - Generic base class for outputting formatted messages.
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 METHODS
 
