@@ -1,8 +1,10 @@
 package App::GitGot::Outputter::dark;
-$App::GitGot::Outputter::dark::VERSION = '1.20';
+$App::GitGot::Outputter::dark::VERSION = '1.21';
 # ABSTRACT: Color scheme appropriate for dark terminal backgrounds
 use Mouse;
 extends 'App::GitGot::Outputter';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -45,7 +47,7 @@ App::GitGot::Outputter::dark - Color scheme appropriate for dark terminal backgr
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
