@@ -1,8 +1,10 @@
 package App::GitGot::Outputter::light;
-$App::GitGot::Outputter::light::VERSION = '1.20';
+$App::GitGot::Outputter::light::VERSION = '1.21';
 # ABSTRACT: Color scheme appropriate for dark terminal backgrounds
 use Mouse;
 extends 'App::GitGot::Outputter';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -48,7 +50,7 @@ App::GitGot::Outputter::light - Color scheme appropriate for dark terminal backg
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 AUTHOR
 
