@@ -1,7 +1,9 @@
 package App::GitGot::Repo;
-$App::GitGot::Repo::VERSION = '1.20';
+$App::GitGot::Repo::VERSION = '1.21';
 # ABSTRACT: Base repository objects
 use Mouse;
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -103,7 +105,7 @@ sub in_writable_format {
 sub remove_tags {
   my( $self, @tags ) = @_;
 
-  %verboten = map { $_ => 1 } @tags;
+  my %verboten = map { $_ => 1 } @tags;
 
   $self->tags( join ' ', grep { !$verboten{$_} } split ' ', $self->tags );
 }
@@ -123,7 +125,7 @@ App::GitGot::Repo - Base repository objects
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 METHODS
 
