@@ -1,8 +1,10 @@
 package App::GitGot::Repo::Git;
-$App::GitGot::Repo::Git::VERSION = '1.20';
+$App::GitGot::Repo::Git::VERSION = '1.21';
 # ABSTRACT: Git repo objects
 use Mouse;
 extends 'App::GitGot::Repo';
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -105,7 +107,7 @@ App::GitGot::Repo::Git - Git repo objects
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 METHODS
 
