@@ -1,7 +1,9 @@
 package App::GitGot::Repositories;
-$App::GitGot::Repositories::VERSION = '1.20';
+$App::GitGot::Repositories::VERSION = '1.21';
 # ABSTRACT: Object holding a collection of repositories
 use Mouse;
+use strict;
+use warnings;
 use 5.010;
 use namespace::autoclean;
 
@@ -53,7 +55,7 @@ App::GitGot::Repositories - Object holding a collection of repositories
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 METHODS
 
